from bigletters.carte import carte
import sys

def main():
    if len(sys.argv) > 1:
        text = " ".join(sys.argv[1:])
    else:
        import easygui
        text = easygui.enterbox("type something.")
        text = text.upper()
    cache = [""] * 10
    for letter in text:
        order = "ABCDEFGHIJKLMNOPQRSTUVWXYZ "
        try:
            i = order.index(letter)
        except ValueError:
            i = order.index(' ')
            j = (i//6)*10
            i = (i%6)*10
        for y in range(j, j+10):
            row = ""
            for x in range(i, i+10):
                pix = carte[y][x]
                row += letter if pix == "X" else " "
                cache[y - j] += row

    for line in cache:
        print(line)

if __name__ == "__main__":
    main()



from PIL import Image
carte = Image.open('bigletters/abcd.png').convert('RGB')
print "carte = ["
for y in range(0, carte.height):
    row = ""
    for x in range(0, carte.width):
        pix, _, _ = carte.getpixel((x, y))
        row += "X" if pix < 1 else " "
    print '\t"{}"{}'.format(row, ',' if y < carte.height -1 else '')
print "]"



carte = [
	"                                                            ",
	"                                                            ",
	"     X       XXXX        XXX    XXXXX      XXXXX     XXXX   ",
	"    X X      X   X      X   X   X   XX     X         X      ",
	"    X X      X   X     X        X    X     X         X      ",
	"   X   X     XXXX      X        X    X     XXXXX     XXXX   ",
	"   XXXXX     X   X     X        X    X     X         X      ",
	"   X   X     X   X      X   X   X   XX     X         X      ",
	"  X     X    XXXX        XXX    XXXXX      XXXXX     X      ",
	"                                                            ",
	"                                                            ",
	"                          X        X       X   X      X     ",
	"   XXXX      X    X       X        X       X  X       X     ",
	"  XX   X     X    X       X        X       X X        X     ",
	"  X          X    X       X        X       XX         X     ",
	"  X  XXX     XXXXXX       X        X       X X        X     ",
	"  X    X     X    X       X        X       X  X       X     ",
	"  XX   X     X    X       X        X       X   X      XXXXX ",
	"   XXXX      X    X                X                        ",
	"                                 XX                         ",
	"                                                            ",
	"  X     X                                            XXXX   ",
	"  XX   XX    X    X    XXXX       XXXX     XXXX      X   X  ",
	"  XX   XX    XX   X   XX  XX      X   X   XX  XX     X   X  ",
	"  X X X X    X X  X   X    X      X   X   X    X     XXXX   ",
	"  X X X X    X X  X   X    X      XXXX    X    X     X  X   ",
	"  X  X  X    X  X X   X    X      X       X    X     X   X  ",
	"  X     X    X   XX   XX  XX      X       XX  X      X    X ",
	"             X    X    XXXX       X        XXX              ",
	"                                              X             ",
	"                                                            ",
	"     XXX              X    X            X   X   X           ",
	"    X   X    XXXXX    X    X    X     X X   X   X   XX  XX  ",
	"    X          X      X    X    X     X  X X X X     X  X   ",
	"     XXX       X      X    X     X   X   X X X X      XX    ",
	"        X      X      X    X     X   X   X X X X      XX    ",
	"    X   X      X      X    X      X X     X   X       XX    ",
	"     XXX       X       XXXX       X X     X   X      X  X   ",
	"               X                   X                XX  XX  ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"   X     X   XXXXXX                                         ",
	"    X   X        X                                          ",
	"     X X        X                                           ",
	"      X        XX                                           ",
	"      X        X                                            ",
	"      X       X                                             ",
	"      X      XXXXXX                                         ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            "
]



#!/usr/bin/env python

import sys
from setuptools import setup

install_requires = [
    "easygui"
]

setup(name="bigletters",
      version="0.4.3",
      author="Leo Fitzpatrick",
      author_email="leocfitz@gmail.com",
      description="It makes letters bigger!",
      packages=["bigletters"],
      entry_points={
          "console_scripts": [
              "bigletters=bigletters.main:main"
          ]
      },
      install_requires=install_requires,
      url="https://gliggy.github.io/Gligslife/"
      )
